pub struct ExtraData<'a> {
pub branch: &'a str,
pub tags: &'a [&'a str],
}Expand description
Contains extra data about the git repository.
Note
This will only be present if the dependency is specified as a git
dependency when used in the Cargo.toml file. When a dependency
is downloaded from crates.io, the git
history and repository metadata is not downloaded, and so this
information will not be available.
Fields
branch: &'a strThe name of the branch.
Tags associated with the current commit.